@@ -8,7 +8,7 @@ use base qw( Exporter );
 
 @AnyEvent::Mojo::EXPORT = qw( mojo_server );
 
-our $VERSION = '0.6001';
+our $VERSION = '0.6002';
 
 
 #####################
@@ -123,6 +123,16 @@ Pedro Melo, C<< <melo at cpan.org> >>
 
 
 
+=head1 CREDITS
+
+In alphabetical order:
+
+Lars Balker Rasmussen
+
+Sebastian Riedel
+
+
+
 =head1 COPYRIGHT & LICENSE
 
 Copyright 2008 Pedro Melo.
